@@ -3,6 +3,7 @@
 
 """
 #print "Package at {0}".format(__path__[0])
+import importlib
 
 __all__ = ['globaling', 'aiding', 'excepting', 'interfacing',
            'registering', 'storing', 'skedding',
@@ -13,6 +14,5 @@ __all__ = ['globaling', 'aiding', 'excepting', 'interfacing',
 
 
 for m in __all__:
-    exec("from . import {0}".format(m)) #relative import
-    #print "Imported {0}".format(globals().get(m,''))
+    importlib.import_module(".{0}".format(m), package='ioflo.base')
 
