@@ -1,10 +1,9 @@
+
+import ioflo.base.registering as registering
+
 def TestRegistry():
     """Module self test
-
-
-
     """
-    
     x = Registry()
     print x.name
     y = Registry()
@@ -15,4 +14,6 @@ def TestRegistry():
         z = Registry(name= name)
     print Registry.Names
     print Registry.VerifyName(name)
-    
\ No newline at end of file
+
+if __name__ == "__main__":
+    TestRegistry()
